#include "ShaderConstants.fxh"

struct VS_Input
{
    float3 position : POSITION;
    float2 uv : TEXCOORD_0;
#ifdef INSTANCEDSTEREO
    uint instanceID : SV_InstanceID;
#endif
};


struct PS_Input
{
    float4 position : SV_Position;
    float2 uv : TEXCOORD_0;
#ifdef INSTANCEDSTEREO
    uint instanceID : SV_InstanceID;
#endif
};


void main( in VS_Input VSInput, out PS_Input PSInput )
{
#if defined(VR_MODE)
 	const float ROTATION_Y_SPEED = 0.0f;
	const float ROTATION_X_SPEED = 0.0f;
	const float ROTATION_X_SCALE = 0.0f;
	const float ROTATION_X_ADDITION = 0.0f;
#else
	const float ROTATION_Y_SPEED = 1.5f;
	const float ROTATION_X_SPEED = 0.1f;
	const float ROTATION_X_SCALE = 7.0f;
	const float ROTATION_X_ADDITION = 20.0f;
#endif	
    float s;
    float c;
    sincos(radians(-TOTAL_REAL_WORLD_TIME * ROTATION_Y_SPEED), s, c);

    float4x4 rotationY = {
        float4(c, 0, s, 0),
        float4(0, 1, 0, 0),
        float4(-s, 0, c, 0),
        float4(0, 0, 0, 1)
	};
	
    sincos(radians(sin(TOTAL_REAL_WORLD_TIME * ROTATION_X_SPEED) * ROTATION_X_SCALE + ROTATION_X_ADDITION), s, c);
    float4x4 rotationX = {
        float4(1, 0, 0, 0),
        float4(0, c, -s, 0),
        float4(0, s, c, 0),
        float4(0, 0, 0, 1)
	};
	
    PSInput.uv = VSInput.uv;
#ifdef INSTANCEDSTEREO
    int i = VSInput.instanceID;
    PSInput.position = mul(WORLDVIEWPROJ_STEREO[i], mul(rotationX, mul(rotationY, float4( VSInput.position, 1 ))));
    PSInput.instanceID = i;
#else
    PSInput.position = mul(WORLDVIEWPROJ, mul(rotationX, mul(rotationY, float4(VSInput.position, 1))));
#endif
}